@@ -179,6 +179,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -204,8 +206,8 @@ class ApiGatewayToIot(
         iot_endpoint: builtins.str,
         api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
         api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -220,6 +222,10 @@ class ApiGatewayToIot(
         :since: 0.8.0
         :summary: Constructs a new instance of the ApiGatewayIot class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToIot.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToIotProps(
             iot_endpoint=iot_endpoint,
             api_gateway_create_api_key=api_gateway_create_api_key,
@@ -269,8 +275,8 @@ class ApiGatewayToIotProps:
         iot_endpoint: builtins.str,
         api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
         api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''The properties for the ApiGatewayIot class.
 
@@ -284,6 +290,13 @@ class ApiGatewayToIotProps:
             api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToIotProps.__init__)
+            check_type(argname="argument iot_endpoint", value=iot_endpoint, expected_type=type_hints["iot_endpoint"])
+            check_type(argname="argument api_gateway_create_api_key", value=api_gateway_create_api_key, expected_type=type_hints["api_gateway_create_api_key"])
+            check_type(argname="argument api_gateway_execution_role", value=api_gateway_execution_role, expected_type=type_hints["api_gateway_execution_role"])
+            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "iot_endpoint": iot_endpoint,
         }
